import type { TagsBase } from '../../../storage/BaseRecord';
import type { AutoAcceptCredential } from '../CredentialAutoAcceptType';
import type { CredentialState } from '../CredentialState';
import { Attachment } from '../../../decorators/attachment/Attachment';
import { BaseRecord } from '../../../storage/BaseRecord';
import { ProposeCredentialMessage, IssueCredentialMessage, RequestCredentialMessage, OfferCredentialMessage, CredentialPreviewAttribute } from '../messages';
import { CredentialInfo } from '../models/CredentialInfo';
export interface CredentialRecordMetadata {
    requestMetadata?: Record<string, unknown>;
    credentialDefinitionId?: string;
    schemaId?: string;
}
export interface CredentialRecordProps {
    id?: string;
    createdAt?: Date;
    state: CredentialState;
    connectionId?: string;
    threadId: string;
    credentialId?: string;
    metadata?: CredentialRecordMetadata;
    tags?: CustomCredentialTags;
    proposalMessage?: ProposeCredentialMessage;
    offerMessage?: OfferCredentialMessage;
    requestMessage?: RequestCredentialMessage;
    credentialMessage?: IssueCredentialMessage;
    credentialAttributes?: CredentialPreviewAttribute[];
    autoAcceptCredential?: AutoAcceptCredential;
    linkedAttachments?: Attachment[];
}
export declare type CustomCredentialTags = TagsBase;
export declare type DefaultCredentialTags = {
    threadId: string;
    connectionId?: string;
    state: CredentialState;
    credentialId?: string;
};
export declare class CredentialRecord extends BaseRecord<DefaultCredentialTags, CustomCredentialTags> {
    connectionId?: string;
    threadId: string;
    credentialId?: string;
    state: CredentialState;
    metadata: CredentialRecordMetadata;
    autoAcceptCredential?: AutoAcceptCredential;
    proposalMessage?: ProposeCredentialMessage;
    offerMessage?: OfferCredentialMessage;
    requestMessage?: RequestCredentialMessage;
    credentialMessage?: IssueCredentialMessage;
    credentialAttributes?: CredentialPreviewAttribute[];
    linkedAttachments?: Attachment[];
    static readonly type = "CredentialRecord";
    readonly type = "CredentialRecord";
    constructor(props: CredentialRecordProps);
    getTags(): {
        threadId: string;
        connectionId: string | undefined;
        state: CredentialState;
        credentialId: string | undefined;
    };
    getCredentialInfo(): CredentialInfo | null;
    assertState(expectedStates: CredentialState | CredentialState[]): void;
    assertConnection(currentConnectionId: string): void;
}
