"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProofRequest = void 0;
const class_transformer_1 = require("class-transformer");
const class_validator_1 = require("class-validator");
const JsonTransformer_1 = require("../../../utils/JsonTransformer");
const transformers_1 = require("../../../utils/transformers");
const credentials_1 = require("../../credentials");
const ProofAttributeInfo_1 = require("./ProofAttributeInfo");
const ProofPredicateInfo_1 = require("./ProofPredicateInfo");
/**
 * Proof Request for Indy based proof format
 *
 * @see https://github.com/hyperledger/indy-sdk/blob/57dcdae74164d1c7aa06f2cccecaae121cefac25/libindy/src/api/anoncreds.rs#L1222-L1239
 */
class ProofRequest {
    constructor(options) {
        var _a, _b;
        if (options) {
            this.name = options.name;
            this.version = options.version;
            this.nonce = options.nonce;
            this.requestedAttributes = (_a = options.requestedAttributes) !== null && _a !== void 0 ? _a : {};
            this.requestedPredicates = (_b = options.requestedPredicates) !== null && _b !== void 0 ? _b : {};
            this.nonRevoked = options.nonRevoked;
            this.ver = options.ver;
        }
    }
    toJSON() {
        // IndyProofRequest is indy-sdk json type
        return JsonTransformer_1.JsonTransformer.toJSON(this);
    }
}
__decorate([
    class_validator_1.IsString(),
    __metadata("design:type", String)
], ProofRequest.prototype, "name", void 0);
__decorate([
    class_validator_1.IsString(),
    __metadata("design:type", String)
], ProofRequest.prototype, "version", void 0);
__decorate([
    class_validator_1.IsString(),
    __metadata("design:type", String)
], ProofRequest.prototype, "nonce", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'requested_attributes' }),
    class_validator_1.ValidateNested({ each: true }),
    transformers_1.RecordTransformer(ProofAttributeInfo_1.ProofAttributeInfo),
    __metadata("design:type", Object)
], ProofRequest.prototype, "requestedAttributes", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'requested_predicates' }),
    class_validator_1.ValidateNested({ each: true }),
    transformers_1.RecordTransformer(ProofPredicateInfo_1.ProofPredicateInfo),
    __metadata("design:type", Object)
], ProofRequest.prototype, "requestedPredicates", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'non_revoked' }),
    class_validator_1.ValidateNested(),
    class_transformer_1.Type(() => credentials_1.RevocationInterval),
    class_validator_1.IsOptional(),
    __metadata("design:type", credentials_1.RevocationInterval)
], ProofRequest.prototype, "nonRevoked", void 0);
__decorate([
    class_validator_1.IsIn(['1.0', '2.0']),
    class_validator_1.IsOptional(),
    __metadata("design:type", String)
], ProofRequest.prototype, "ver", void 0);
exports.ProofRequest = ProofRequest;
//# sourceMappingURL=ProofRequest.js.map